﻿using Windows.Foundation;
using Windows.Graphics.Display;
using Windows.UI.ViewManagement;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Media.Animation;

namespace TestProject
{
    /// <summary>
    /// 메인 페이지
    /// </summary>
    public sealed partial class MainPage : Page
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainPage()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainPage()
        {
            InitializeComponent();

            #region 윈도우 크기를 설정한다.

            double width  = 800d;
            double height = 600d;

            double dpi = (double)DisplayInformation.GetForCurrentView().LogicalDpi;

            ApplicationView.PreferredLaunchWindowingMode = ApplicationViewWindowingMode.PreferredLaunchViewSize;

            Size windowSize = new Size(width * 96d / dpi, height * 96d / dpi);

            ApplicationView.PreferredLaunchViewSize = windowSize;

            Window.Current.Activate();

            ApplicationView.GetForCurrentView().TryResizeView(windowSize);

            #endregion
            #region 윈도우 제목을 설정한다.

            ApplicationView.GetForCurrentView().Title = "ConnectedAnimation 클래스 : 단순 연결 애니메이션 사용하기";

            #endregion

            this.frame.Navigate(typeof(SamplePage1));
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private
        //////////////////////////////////////////////////////////////////////////////// Event

        #region 탐색하기 버튼 클릭시 처리하기 - navigateButton_Click(sender, e)

        /// <summary>
        /// 탐색하기 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void navigateButton_Click(object sender, RoutedEventArgs e)
        {
            object currentContent = this.frame.Content;

            if(currentContent as SamplePage1 != null)
            {
                (currentContent as SamplePage1).PrepareConnectedAnimation(GetConfiguration());

                this.frame.Navigate(typeof(SamplePage2), null, new SuppressNavigationTransitionInfo());
            }
            else if(currentContent as SamplePage2 != null)
            {
                (currentContent as SamplePage2).PrepareConnectedAnimation(GetConfiguration());

                this.frame.Navigate(typeof(SamplePage1), null, new SuppressNavigationTransitionInfo());
            }
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////// Function

        #region 구성 구하기 - GetConfiguration()

        /// <summary>
        /// 구성 구하기
        /// </summary>
        /// <returns>구성</returns>
        private ConnectedAnimationConfiguration GetConfiguration()
        {
            RadioButton radioButton = this.radioButtons.SelectedItem as RadioButton;

            string configurationName = radioButton.Content.ToString();

            switch(configurationName)
            {
                case "Gravity" : return new GravityConnectedAnimationConfiguration();
                case "Direct"  : return new DirectConnectedAnimationConfiguration();
                case "Basic"   : return new BasicConnectedAnimationConfiguration();
                default        : return null;
            }
        }

        #endregion
    }
}